==> droogle_hangout-8.x-1.0.tar.gz: droogle_hangout/src/Form/DroogleHangoutSettingsForm.php <==
<?php

/**
 * @file
 * Contains \Drupal\droogle_hangout\Form\DroogleHangoutSettingsForm.
 */

namespace Drupal\droogle_hangout\Form;

use Drupal\Component\Utility\String;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form to configure maintenance settings for this site.
 */
class DroogleHangoutSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'droogle_hangout_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('droogle_hangout.droogle');

    $form['droogle_hangout'] = array(
      '#type' => 'fieldset',
      '#title' => t('Settings for Google Console'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['droogle_hangout']['droogle_hangout_master_account_email'] = array(
      '#type' => 'textfield',
      '#title' => t('Email address connecting to the Google Console.'),
      '#description' => t('Enter the email address used for your Google Console that is handling the api.'),
      '#default_value' => $config->get('email'),
    );

    $form['droogle_hangout']['droogle_hangout_clientid'] = array(
      '#type' => 'textfield',
      '#title' => t('Google Console Client ID'),
      '#description' => t('Enter the Google Client ID to use.  Visit https://cloud.google.com/console to generate a Client ID.'),
      '#default_value' => $config->get('clientid'),
    );

  $form['droogle_hangout']['droogle_hangout_client_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Console Client Secret'),
    '#description' => t('Enter the Google Client Secret to use.  Visit https://cloud.google.com/console to generate a Google Client Secret.'),
    '#default_value' => $config->get('secret'),
  );
  $form['droogle_hangout']['droogle_hangout_refresh_token'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Refresh Token'),
    '#description' => t('Enter the google refresh token created at https://developers.google.com/oauthplayground.'),
    '#default_value' => $config->get('token'),
  );

  $form['droogle_hangout_css'] = array(
    '#type' => 'fieldset',
    '#title' => t('Custom CSS rules for Droogle Hangout'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['droogle_hangout_css']['droogle_hangout_custom_css'] = array(
    '#type' => 'textarea',
    '#title' => t('Custom CSS for Hangout popup window'),
    '#rows' => 10,
    '#description' => t('Add CSS rules as if this textarea were an actual CSS file'),
    '#default_value' => $config->get('css'),
  );

//  $form['#submit'][] = 'droogle_hangout_write_css_file';

    return parent::buildForm($form, $form_state);
  }
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('droogle_hangout.droogle')
      ->set('email', String::checkPlain($form_state->getValue('droogle_hangout_master_account_email')))
      ->set('clientid', String::checkPlain($form_state->getValue('droogle_hangout_clientid')))
      ->set('secret', String::checkPlain($form_state->getValue('droogle_hangout_client_secret')))
      ->set('token', String::checkPlain($form_state->getValue('droogle_hangout_refresh_token')))
      ->set('css', String::checkPlain($form_state->getValue('droogle_hangout_custom_css')))
      ->save();
    parent::submitForm($form, $form_state);

    global $base_url;
    // Hangout popup box.
    $default_css = '#content #block-droogle-hangout-droogle-hangout-invites h2,' . "\n";
    $default_css .= '#block-droogle-hangout-droogle-hangout-invites h2 {' . "\n";
    $default_css .= '  background-color: #629540;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '.slant-45 {' . "\n";
    $default_css .= '  border-right: 20px solid #629540;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '#hangout-invite-header {' . "\n";
    $default_css .= '  background-color: #629540;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '#hangout-invite-popup {' . "\n";
    $default_css .= '  border: solid 5px #629540;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '.hangout-btn-bubble {' . "\n";
    $default_css .= '  background-color: #9fc56d;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '.hangout-btn-bubble:after {' . "\n";
    $default_css .= '  border-right: 8px solid #9fc56d;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '#google-popup-logo {' . "\n";
    $default_css .= '  background: url(' . $base_url . '/modules/custom/droogle_hangout/images/hangout_logo_green.png) no-repeat 0 0 transparent;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '#close-hangout-invite-popup:hover {' . "\n";
    $default_css .= '  background-color: #427520;' . "\n";
    $default_css .= '}' . "\n\n";
    // Hangout sent message box.
    $default_css .= '.hangout-sent {' . "\n";
    $default_css .= '  border: solid 3px #629540;' . "\n";
    $default_css .= '  border-top: solid 20px #629540;' . "\n";
    $default_css .= '}' . "\n\n";
    $default_css .= '.hangout-sent a:visited,' . "\n";
    $default_css .= '.hangout-sent a {' . "\n";
    $default_css .= '  background-color: #528530;' . "\n";
    $default_css .= '}' . "\n";

    $custom_css_file = drupal_get_path('module', 'droogle_hangout') . '/css/droogle_hangout_custom.css';
    if ($wrapper = file_stream_wrapper_get_instance_by_uri('public://')) {
      $realpath = $wrapper->realpath();
      file_unmanaged_copy($custom_css_file, $realpath, FILE_EXISTS_REPLACE);
      $droogle_hangout_custom_css = String::checkPlain($form_state->getValue('droogle_hangout_custom_css'));
      file_put_contents($realpath . '/droogle_hangout_custom.css', $default_css . $droogle_hangout_custom_css);
    }
  }
}

==> droogle_hangout-8.x-1.3.tar.gz: droogle_hangout/src/Form/DroogleHangoutSettingsForm.php <==
<?php

/**
 * @file
 * Contains \Drupal\droogle_hangout\Form\DroogleHangoutSettingsForm.
 */

namespace Drupal\droogle_hangout\Form;

use Drupal\Component\Utility\SafeMarkup;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form to configure maintenance settings for this site.
 */
class DroogleHangoutSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'droogle_hangout_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['droogle_hangout.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('droogle_hangout.droogle');

    $form['droogle_hangout'] = array(
      '#type' => 'fieldset',
      '#title' => t('Settings for Google Console'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    $form['droogle_hangout']['droogle_hangout_master_account_email'] = array(
      '#type' => 'textfield',
      '#title' => t('Email address connecting to the Google Console.'),
      '#description' => t('Enter the email address used for your Google Console that is handling the api.'),
      '#default_value' => $config->get('email'),
    );

    $form['droogle_hangout']['droogle_hangout_clientid'] = array(
      '#type' => 'textfield',
      '#title' => t('Google Console Client ID'),
      '#description' => t('Enter the Google Client ID to use.  Visit https://cloud.google.com/console to generate a Client ID.'),
      '#default_value' => $config->get('clientid'),
    );

  $form['droogle_hangout']['droogle_hangout_client_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Console Client Secret'),
    '#description' => t('Enter the Google Client Secret to use.  Visit https://cloud.google.com/console to generate a Google Client Secret.'),
    '#default_value' => $config->get('secret'),
  );
  $form['droogle_hangout']['droogle_hangout_refresh_token'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Refresh Token'),
    '#description' => t('Enter the google refresh token created at https://developers.google.com/oauthplayground.'),
    '#default_value' => $config->get('token'),
  );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    \Drupal::configFactory()->getEditable('droogle_hangout.droogle')
      ->set('email', SafeMarkup::checkPlain($form_state->getValue('droogle_hangout_master_account_email')))
      ->set('clientid', SafeMarkup::checkPlain($form_state->getValue('droogle_hangout_clientid')))
      ->set('secret', SafeMarkup::checkPlain($form_state->getValue('droogle_hangout_client_secret')))
      ->set('token', SafeMarkup::checkPlain($form_state->getValue('droogle_hangout_refresh_token')))
      ->save();
    parent::submitForm($form, $form_state);
  }
}
